
from gi.repository import GObject

def client_interface_info(*args, **kwargs): ...
def client_override_properties(*args, **kwargs): ...
def location_interface_info(*args, **kwargs): ...
def location_override_properties(*args, **kwargs): ...
def manager_interface_info(*args, **kwargs): ...
def manager_override_properties(*args, **kwargs): ...

class Client:
    def call_start(*args, **kwargs): ...
    def call_start_finish(*args, **kwargs): ...
    def call_start_sync(*args, **kwargs): ...
    def call_stop(*args, **kwargs): ...
    def call_stop_finish(*args, **kwargs): ...
    def call_stop_sync(*args, **kwargs): ...
    def complete_start(*args, **kwargs): ...
    def complete_stop(*args, **kwargs): ...
    def emit_location_updated(*args, **kwargs): ...
    def interface_info(*args, **kwargs): ...
    def override_properties(*args, **kwargs): ...
    

class ClientProxy:
    def create(*args, **kwargs): ...
    def create_finish(*args, **kwargs): ...
    def create_full(*args, **kwargs): ...
    def create_full_finish(*args, **kwargs): ...
    def create_full_sync(*args, **kwargs): ...
    def create_sync(*args, **kwargs): ...
    

class ClientSkeleton:
    def new(*args, **kwargs): ...
    

class Location:
    def interface_info(*args, **kwargs): ...
    def override_properties(*args, **kwargs): ...
    

class LocationProxy: ...

class LocationSkeleton:
    def new(*args, **kwargs): ...
    

class Manager:
    def call_add_agent(*args, **kwargs): ...
    def call_add_agent_finish(*args, **kwargs): ...
    def call_add_agent_sync(*args, **kwargs): ...
    def call_create_client(*args, **kwargs): ...
    def call_create_client_finish(*args, **kwargs): ...
    def call_create_client_sync(*args, **kwargs): ...
    def call_delete_client(*args, **kwargs): ...
    def call_delete_client_finish(*args, **kwargs): ...
    def call_delete_client_sync(*args, **kwargs): ...
    def call_get_client(*args, **kwargs): ...
    def call_get_client_finish(*args, **kwargs): ...
    def call_get_client_sync(*args, **kwargs): ...
    def complete_add_agent(*args, **kwargs): ...
    def complete_create_client(*args, **kwargs): ...
    def complete_delete_client(*args, **kwargs): ...
    def complete_get_client(*args, **kwargs): ...
    def interface_info(*args, **kwargs): ...
    def override_properties(*args, **kwargs): ...
    

class ManagerProxy: ...

class ManagerSkeleton:
    def new(*args, **kwargs): ...
    

class Simple:
    parent = ...
    priv = ...
    
    def get_client(*args, **kwargs): ...
    def get_location(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def new_sync(*args, **kwargs): ...
    

class ClientProxyCreateFlags(GObject.GFlags):
    NONE = ...
    AUTO_DELETE = ...

class AccuracyLevel(GObject.GEnum):
    NONE = ...
    COUNTRY = ...
    CITY = ...
    NEIGHBORHOOD = ...
    STREET = ...
    EXACT = ...




from gi.repository import GObject


ENCODING_CATEGORY_CAPTURE: str = ...
ENCODING_CATEGORY_DEVICE: str = ...
ENCODING_CATEGORY_FILE_EXTENSION: str = ...
ENCODING_CATEGORY_ONLINE_SERVICE: str = ...
ENCODING_CATEGORY_STORAGE_EDITING: str = ...
PLUGINS_BASE_VERSION_MAJOR: int = ...
PLUGINS_BASE_VERSION_MICRO: int = ...
PLUGINS_BASE_VERSION_MINOR: int = ...
PLUGINS_BASE_VERSION_NANO = ...
_namespace: str = ...
_version: str = ...

def codec_utils_aac_caps_set_level_and_profile(*args, **kwargs): ...
def codec_utils_aac_get_channels(*args, **kwargs): ...
def codec_utils_aac_get_index_from_sample_rate(*args, **kwargs): ...
def codec_utils_aac_get_level(*args, **kwargs): ...
def codec_utils_aac_get_profile(*args, **kwargs): ...
def codec_utils_aac_get_sample_rate(*args, **kwargs): ...
def codec_utils_aac_get_sample_rate_from_index(*args, **kwargs): ...
def codec_utils_h264_caps_set_level_and_profile(*args, **kwargs): ...
def codec_utils_h264_get_level(*args, **kwargs): ...
def codec_utils_h264_get_level_idc(*args, **kwargs): ...
def codec_utils_h264_get_profile(*args, **kwargs): ...
def codec_utils_h265_caps_set_level_tier_and_profile(*args, **kwargs): ...
def codec_utils_h265_get_level(*args, **kwargs): ...
def codec_utils_h265_get_level_idc(*args, **kwargs): ...
def codec_utils_h265_get_profile(*args, **kwargs): ...
def codec_utils_h265_get_tier(*args, **kwargs): ...
def codec_utils_mpeg4video_caps_set_level_and_profile(*args, **kwargs): ...
def codec_utils_mpeg4video_get_level(*args, **kwargs): ...
def codec_utils_mpeg4video_get_profile(*args, **kwargs): ...
def codec_utils_opus_create_caps(*args, **kwargs): ...
def codec_utils_opus_create_caps_from_header(*args, **kwargs): ...
def codec_utils_opus_create_header(*args, **kwargs): ...
def codec_utils_opus_parse_caps(*args, **kwargs): ...
def codec_utils_opus_parse_header(*args, **kwargs): ...
def encoding_list_all_targets(*args, **kwargs): ...
def encoding_list_available_categories(*args, **kwargs): ...
def install_plugins_async(*args, **kwargs): ...
def install_plugins_installation_in_progress(*args, **kwargs): ...
def install_plugins_return_get_name(*args, **kwargs): ...
def install_plugins_supported(*args, **kwargs): ...
def install_plugins_sync(*args, **kwargs): ...
def is_missing_plugin_message(*args, **kwargs): ...
def missing_decoder_installer_detail_new(*args, **kwargs): ...
def missing_decoder_message_new(*args, **kwargs): ...
def missing_element_installer_detail_new(*args, **kwargs): ...
def missing_element_message_new(*args, **kwargs): ...
def missing_encoder_installer_detail_new(*args, **kwargs): ...
def missing_encoder_message_new(*args, **kwargs): ...
def missing_plugin_message_get_description(*args, **kwargs): ...
def missing_plugin_message_get_installer_detail(*args, **kwargs): ...
def missing_uri_sink_installer_detail_new(*args, **kwargs): ...
def missing_uri_sink_message_new(*args, **kwargs): ...
def missing_uri_source_installer_detail_new(*args, **kwargs): ...
def missing_uri_source_message_new(*args, **kwargs): ...
def pb_utils_add_codec_description_to_tag_list(*args, **kwargs): ...
def pb_utils_get_codec_description(*args, **kwargs): ...
def pb_utils_get_decoder_description(*args, **kwargs): ...
def pb_utils_get_element_description(*args, **kwargs): ...
def pb_utils_get_encoder_description(*args, **kwargs): ...
def pb_utils_get_sink_description(*args, **kwargs): ...
def pb_utils_get_source_description(*args, **kwargs): ...
def pb_utils_init(*args, **kwargs): ...
def plugins_base_version(*args, **kwargs): ...
def plugins_base_version_string(*args, **kwargs): ...

class AudioVisualizer:
    ainfo = ...
    priv = ...
    req_spf = ...
    vinfo = ...
    
    def do_decide_allocation(self, *args, **kwargs): ...
    def do_render(self, *args, **kwargs): ...
    def do_setup(self, *args, **kwargs): ...
    

class Discoverer:
    _reserved = ...
    parent = ...
    priv = ...
    
    def discover_uri(self, uri: str) -> DiscovererInfo: ...
    def discover_uri_async(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def start(*args, **kwargs): ...
    def stop(*args, **kwargs): ...
    
    def do_discovered(self, *args, **kwargs): ...
    def do_finished(self, *args, **kwargs): ...
    def do_source_setup(self, *args, **kwargs): ...
    def do_starting(self, *args, **kwargs): ...
    

class DiscovererAudioInfo:
    def get_bitrate(*args, **kwargs): ...
    def get_channel_mask(*args, **kwargs): ...
    def get_channels(*args, **kwargs): ...
    def get_depth(*args, **kwargs): ...
    def get_language(*args, **kwargs): ...
    def get_max_bitrate(*args, **kwargs): ...
    def get_sample_rate(*args, **kwargs): ...
    

class DiscovererContainerInfo:
    def get_streams(*args, **kwargs): ...


class DiscovererInfo:
    def copy(*args, **kwargs): ...
    def from_variant(*args, **kwargs): ...
    def get_audio_streams(self) -> list[DiscovererStreamInfo]: ...
    def get_container_streams(*args, **kwargs): ...
    def get_duration(*args, **kwargs): ...
    def get_live(*args, **kwargs): ...
    def get_misc(*args, **kwargs): ...
    def get_missing_elements_installer_details(*args, **kwargs): ...
    def get_result(*args, **kwargs): ...
    def get_seekable(*args, **kwargs): ...
    def get_stream_info(*args, **kwargs): ...
    def get_stream_list(*args, **kwargs): ...
    def get_streams(*args, **kwargs): ...
    def get_subtitle_streams(*args, **kwargs): ...
    def get_tags(*args, **kwargs): ...
    def get_toc(*args, **kwargs): ...
    def get_uri(*args, **kwargs): ...
    def get_video_streams(*args, **kwargs): ...
    def to_variant(*args, **kwargs): ...
    

class DiscovererStreamInfo:
    def get_caps(*args, **kwargs): ...
    def get_misc(*args, **kwargs): ...
    def get_next(*args, **kwargs): ...
    def get_previous(*args, **kwargs): ...
    def get_stream_id(*args, **kwargs): ...
    def get_stream_type_nick(*args, **kwargs): ...
    def get_tags(*args, **kwargs): ...
    def get_toc(*args, **kwargs): ...
    def list_free(*args, **kwargs): ...
    

class DiscovererSubtitleInfo:
    def get_language(*args, **kwargs): ...
    

class DiscovererVideoInfo:
    def get_bitrate(*args, **kwargs): ...
    def get_depth(*args, **kwargs): ...
    def get_framerate_denom(*args, **kwargs): ...
    def get_framerate_num(*args, **kwargs): ...
    def get_height(*args, **kwargs): ...
    def get_max_bitrate(*args, **kwargs): ...
    def get_par_denom(*args, **kwargs): ...
    def get_par_num(*args, **kwargs): ...
    def get_width(*args, **kwargs): ...
    def is_image(*args, **kwargs): ...
    def is_interlaced(*args, **kwargs): ...
    

class EncodingAudioProfile:
    def new(*args, **kwargs): ...
    

class EncodingContainerProfile:
    def add_profile(*args, **kwargs): ...
    def contains_profile(*args, **kwargs): ...
    def get_profiles(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    

class EncodingProfile:
    def copy(*args, **kwargs): ...
    def find(*args, **kwargs): ...
    def from_discoverer(*args, **kwargs): ...
    def get_allow_dynamic_output(*args, **kwargs): ...
    def get_description(*args, **kwargs): ...
    def get_file_extension(*args, **kwargs): ...
    def get_format(*args, **kwargs): ...
    def get_input_caps(*args, **kwargs): ...
    def get_name(*args, **kwargs): ...
    def get_presence(*args, **kwargs): ...
    def get_preset(*args, **kwargs): ...
    def get_preset_name(*args, **kwargs): ...
    def get_restriction(*args, **kwargs): ...
    def get_single_segment(*args, **kwargs): ...
    def get_type_nick(*args, **kwargs): ...
    def is_enabled(*args, **kwargs): ...
    def is_equal(*args, **kwargs): ...
    def set_allow_dynamic_output(*args, **kwargs): ...
    def set_description(*args, **kwargs): ...
    def set_enabled(*args, **kwargs): ...
    def set_format(*args, **kwargs): ...
    def set_name(*args, **kwargs): ...
    def set_presence(*args, **kwargs): ...
    def set_preset(*args, **kwargs): ...
    def set_preset_name(*args, **kwargs): ...
    def set_restriction(*args, **kwargs): ...
    def set_single_segment(*args, **kwargs): ...
    

class EncodingTarget:
    def add_profile(*args, **kwargs): ...
    def get_category(*args, **kwargs): ...
    def get_description(*args, **kwargs): ...
    def get_name(*args, **kwargs): ...
    def get_path(*args, **kwargs): ...
    def get_profile(*args, **kwargs): ...
    def get_profiles(*args, **kwargs): ...
    def load(*args, **kwargs): ...
    def load_from_file(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def save(*args, **kwargs): ...
    def save_to_file(*args, **kwargs): ...
    

class EncodingVideoProfile:
    def get_pass(*args, **kwargs): ...
    def get_variableframerate(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def set_pass(*args, **kwargs): ...
    def set_variableframerate(*args, **kwargs): ...
    

class InstallPluginsContext:
    def free(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def set_confirm_search(*args, **kwargs): ...
    def set_desktop_id(*args, **kwargs): ...
    def set_startup_notification_id(*args, **kwargs): ...
    def set_xid(*args, **kwargs): ...
    

class DiscovererSerializeFlags(GObject.GFlags):
    BASIC = ...
    CAPS = ...
    TAGS = ...
    MISC = ...
    ALL = ...

class AudioVisualizerShader(GObject.GEnum):
    NONE = ...
    FADE = ...
    FADE_AND_MOVE_UP = ...
    FADE_AND_MOVE_DOWN = ...
    FADE_AND_MOVE_LEFT = ...
    FADE_AND_MOVE_RIGHT = ...
    FADE_AND_MOVE_HORIZ_OUT = ...
    FADE_AND_MOVE_HORIZ_IN = ...
    FADE_AND_MOVE_VERT_OUT = ...
    FADE_AND_MOVE_VERT_IN = ...

class DiscovererResult(GObject.GEnum):
    OK = ...
    URI_INVALID = ...
    ERROR = ...
    TIMEOUT = ...
    BUSY = ...
    MISSING_PLUGINS = ...

class InstallPluginsReturn(GObject.GEnum):
    SUCCESS = ...
    NOT_FOUND = ...
    ERROR = ...
    PARTIAL_SUCCESS = ...
    USER_ABORT = ...
    CRASHED = ...
    INVALID = ...
    STARTED_OK = ...
    INTERNAL_FAILURE = ...
    HELPER_MISSING = ...
    INSTALL_IN_PROGRESS = ...
    get_name = ...




from typing import Optional

from gi.repository import Gtk
from gi.repository import GObject


_namespace: str = ...
_version: str = ...

def completion_error_quark(*args, **kwargs): ...
def encoding_get_all(*args, **kwargs): ...
def encoding_get_current(*args, **kwargs): ...
def encoding_get_default_candidates(*args, **kwargs): ...
def encoding_get_from_charset(*args, **kwargs): ...
def encoding_get_utf8(*args, **kwargs): ...
def file_loader_error_quark(*args, **kwargs): ...
def file_saver_error_quark(*args, **kwargs): ...
def finalize(*args, **kwargs): ...
def init(*args, **kwargs): ...
def utils_escape_search_text(*args, **kwargs): ...
def utils_unescape_search_text(*args, **kwargs): ...


class Buffer(Gtk.TextBuffer):
    def backward_iter_to_source_mark(*args, **kwargs): ...
    def begin_not_undoable_action(*args, **kwargs): ...
    def can_redo(*args, **kwargs): ...
    def can_undo(*args, **kwargs): ...
    def change_case(*args, **kwargs): ...
    def create_source_mark(*args, **kwargs): ...
    def end_not_undoable_action(*args, **kwargs): ...
    def ensure_highlight(*args, **kwargs): ...
    def forward_iter_to_source_mark(*args, **kwargs): ...
    def get_context_classes_at_iter(*args, **kwargs): ...
    def get_highlight_matching_brackets(*args, **kwargs): ...
    def get_highlight_syntax(*args, **kwargs): ...
    def get_implicit_trailing_newline(*args, **kwargs): ...
    def get_language(*args, **kwargs): ...
    def get_max_undo_levels(*args, **kwargs): ...
    def get_source_marks_at_iter(*args, **kwargs): ...
    def get_source_marks_at_line(*args, **kwargs): ...
    def get_style_scheme(*args, **kwargs): ...
    def get_undo_manager(*args, **kwargs): ...
    def iter_backward_to_context_class_toggle(*args, **kwargs): ...
    def iter_forward_to_context_class_toggle(*args, **kwargs): ...
    def iter_has_context_class(*args, **kwargs): ...
    def join_lines(*args, **kwargs): ...
    def new_with_language(*args, **kwargs): ...
    def redo(*args, **kwargs): ...
    def remove_source_marks(*args, **kwargs): ...
    def set_highlight_matching_brackets(*args, **kwargs): ...
    def set_highlight_syntax(*args, **kwargs): ...
    def set_implicit_trailing_newline(*args, **kwargs): ...
    def set_language(self, language: Optional[Language]) -> None: ...
    def set_max_undo_levels(*args, **kwargs): ...
    def set_style_scheme(self, scheme: Optional[StyleScheme]) -> None: ...
    def set_undo_manager(*args, **kwargs): ...
    def sort_lines(*args, **kwargs): ...
    def undo(*args, **kwargs): ...
    
    def do_bracket_matched(self, *args, **kwargs): ...
    def do_redo(self, *args, **kwargs): ...
    def do_undo(self, *args, **kwargs): ...
    

class Completion:
    parent_instance = ...
    priv = ...
    
    def add_provider(*args, **kwargs): ...
    def block_interactive(*args, **kwargs): ...
    def create_context(*args, **kwargs): ...
    def get_info_window(*args, **kwargs): ...
    def get_providers(*args, **kwargs): ...
    def get_view(*args, **kwargs): ...
    def hide(*args, **kwargs): ...
    def remove_provider(*args, **kwargs): ...
    def start(*args, **kwargs): ...
    def unblock_interactive(*args, **kwargs): ...
    
    def do_activate_proposal(self, *args, **kwargs): ...
    def do_hide(self, *args, **kwargs): ...
    def do_move_cursor(self, *args, **kwargs): ...
    def do_move_page(self, *args, **kwargs): ...
    def do_populate_context(self, *args, **kwargs): ...
    def do_proposal_activated(self, *args, **kwargs): ...
    def do_show(self, *args, **kwargs): ...
    

class CompletionContext:
    parent = ...
    priv = ...
    
    def add_proposals(*args, **kwargs): ...
    def get_activation(*args, **kwargs): ...
    def get_iter(*args, **kwargs): ...
    
    def do_cancelled(self, *args, **kwargs): ...
    

class CompletionInfo:
    parent = ...
    
    def move_to_iter(*args, **kwargs): ...
    

class CompletionItem:
    parent = ...
    priv = ...
    
    def new(*args, **kwargs): ...
    def set_gicon(*args, **kwargs): ...
    def set_icon(*args, **kwargs): ...
    def set_icon_name(*args, **kwargs): ...
    def set_info(*args, **kwargs): ...
    def set_label(*args, **kwargs): ...
    def set_markup(*args, **kwargs): ...
    def set_text(*args, **kwargs): ...
    

class CompletionProposal:
    def changed(*args, **kwargs): ...
    def equal(*args, **kwargs): ...
    def get_gicon(*args, **kwargs): ...
    def get_icon(*args, **kwargs): ...
    def get_icon_name(*args, **kwargs): ...
    def get_info(*args, **kwargs): ...
    def get_label(*args, **kwargs): ...
    def get_markup(*args, **kwargs): ...
    def get_text(*args, **kwargs): ...
    def hash(*args, **kwargs): ...
    

class CompletionProvider:
    def activate_proposal(*args, **kwargs): ...
    def get_activation(*args, **kwargs): ...
    def get_gicon(*args, **kwargs): ...
    def get_icon(*args, **kwargs): ...
    def get_icon_name(*args, **kwargs): ...
    def get_info_widget(*args, **kwargs): ...
    def get_interactive_delay(*args, **kwargs): ...
    def get_name(*args, **kwargs): ...
    def get_priority(*args, **kwargs): ...
    def get_start_iter(*args, **kwargs): ...
    def match(*args, **kwargs): ...
    def populate(*args, **kwargs): ...
    def update_info(*args, **kwargs): ...
    

class CompletionWords:
    parent = ...
    priv = ...
    
    def new(*args, **kwargs): ...
    def register(*args, **kwargs): ...
    def unregister(*args, **kwargs): ...
    

class Encoding:
    def free(*args, **kwargs): ...
    def get_all(*args, **kwargs): ...
    def get_charset(*args, **kwargs): ...
    def get_current(*args, **kwargs): ...
    def get_default_candidates(*args, **kwargs): ...
    def get_from_charset(*args, **kwargs): ...
    def get_name(*args, **kwargs): ...
    def get_utf8(*args, **kwargs): ...
    def to_string(*args, **kwargs): ...
    

class File:
    parent = ...
    priv = ...
    
    def check_file_on_disk(*args, **kwargs): ...
    def get_compression_type(*args, **kwargs): ...
    def get_encoding(*args, **kwargs): ...
    def get_location(*args, **kwargs): ...
    def get_newline_type(*args, **kwargs): ...
    def is_deleted(*args, **kwargs): ...
    def is_externally_modified(*args, **kwargs): ...
    def is_local(*args, **kwargs): ...
    def is_readonly(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def set_location(*args, **kwargs): ...
    

class FileLoader:
    parent = ...
    priv = ...
    
    def get_buffer(*args, **kwargs): ...
    def get_compression_type(*args, **kwargs): ...
    def get_encoding(*args, **kwargs): ...
    def get_file(*args, **kwargs): ...
    def get_input_stream(*args, **kwargs): ...
    def get_location(*args, **kwargs): ...
    def get_newline_type(*args, **kwargs): ...
    def load_async(*args, **kwargs): ...
    def load_finish(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def new_from_stream(*args, **kwargs): ...
    def set_candidate_encodings(*args, **kwargs): ...
    

class FileSaver:
    object = ...
    priv = ...
    
    def get_buffer(*args, **kwargs): ...
    def get_compression_type(*args, **kwargs): ...
    def get_encoding(*args, **kwargs): ...
    def get_file(*args, **kwargs): ...
    def get_flags(*args, **kwargs): ...
    def get_location(*args, **kwargs): ...
    def get_newline_type(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def new_with_target(*args, **kwargs): ...
    def save_async(*args, **kwargs): ...
    def save_finish(*args, **kwargs): ...
    def set_compression_type(*args, **kwargs): ...
    def set_encoding(*args, **kwargs): ...
    def set_flags(*args, **kwargs): ...
    def set_newline_type(*args, **kwargs): ...
    

class Gutter:
    parent = ...
    priv = ...
    
    def get_renderer_at_pos(*args, **kwargs): ...
    def get_view(*args, **kwargs): ...
    def get_window_type(*args, **kwargs): ...
    def insert(*args, **kwargs): ...
    def queue_draw(*args, **kwargs): ...
    def remove(*args, **kwargs): ...
    def reorder(*args, **kwargs): ...
    

class GutterRenderer:
    parent = ...
    priv = ...
    
    def activate(*args, **kwargs): ...
    def begin(*args, **kwargs): ...
    def draw(*args, **kwargs): ...
    def end(*args, **kwargs): ...
    def get_alignment(*args, **kwargs): ...
    def get_alignment_mode(*args, **kwargs): ...
    def get_background(*args, **kwargs): ...
    def get_padding(*args, **kwargs): ...
    def get_size(*args, **kwargs): ...
    def get_view(*args, **kwargs): ...
    def get_visible(*args, **kwargs): ...
    def get_window_type(*args, **kwargs): ...
    def query_activatable(*args, **kwargs): ...
    def query_data(*args, **kwargs): ...
    def query_tooltip(*args, **kwargs): ...
    def queue_draw(*args, **kwargs): ...
    def set_alignment(*args, **kwargs): ...
    def set_alignment_mode(*args, **kwargs): ...
    def set_background(*args, **kwargs): ...
    def set_padding(*args, **kwargs): ...
    def set_size(*args, **kwargs): ...
    def set_visible(*args, **kwargs): ...
    
    def do_activate(self, *args, **kwargs): ...
    def do_begin(self, *args, **kwargs): ...
    def do_change_buffer(self, *args, **kwargs): ...
    def do_change_view(self, *args, **kwargs): ...
    def do_draw(self, *args, **kwargs): ...
    def do_end(self, *args, **kwargs): ...
    def do_query_activatable(self, *args, **kwargs): ...
    def do_query_data(self, *args, **kwargs): ...
    def do_query_tooltip(self, *args, **kwargs): ...
    def do_queue_draw(self, *args, **kwargs): ...
    

class GutterRendererPixbuf:
    def get_gicon(*args, **kwargs): ...
    def get_icon_name(*args, **kwargs): ...
    def get_pixbuf(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def set_gicon(*args, **kwargs): ...
    def set_icon_name(*args, **kwargs): ...
    def set_pixbuf(*args, **kwargs): ...
    

class GutterRendererText:
    def measure(*args, **kwargs): ...
    def measure_markup(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def set_markup(*args, **kwargs): ...
    def set_text(*args, **kwargs): ...
    

class Language(GObject.Object):
    parent_instance = ...
    priv = ...
    
    def get_globs(*args, **kwargs): ...
    def get_hidden(*args, **kwargs): ...
    def get_id(*args, **kwargs): ...
    def get_metadata(*args, **kwargs): ...
    def get_mime_types(*args, **kwargs): ...
    def get_name(self) -> str: ...
    def get_section(*args, **kwargs): ...
    def get_style_fallback(*args, **kwargs): ...
    def get_style_ids(*args, **kwargs): ...
    def get_style_name(*args, **kwargs): ...
    

class LanguageManager(GObject.Object):
    parent_instance = ...
    priv = ...
    
    @classmethod
    def get_default(cls) -> LanguageManager: ...
    def get_language(self, id: str) -> Optional[Language]: ...
    def get_language_ids(*args, **kwargs): ...
    def get_search_path(*args, **kwargs): ...
    def guess_language(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def set_search_path(*args, **kwargs): ...
    

class Map:
    def get_view(*args, **kwargs): ...
    def set_view(*args, **kwargs): ...
    

class Mark:
    priv = ...
    
    def get_category(*args, **kwargs): ...
    def next(*args, **kwargs): ...
    def prev(*args, **kwargs): ...
    

class MarkAttributes:
    parent = ...
    priv = ...
    
    def get_background(*args, **kwargs): ...
    def get_gicon(*args, **kwargs): ...
    def get_icon_name(*args, **kwargs): ...
    def get_pixbuf(*args, **kwargs): ...
    def get_tooltip_markup(*args, **kwargs): ...
    def get_tooltip_text(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def render_icon(*args, **kwargs): ...
    def set_background(*args, **kwargs): ...
    def set_gicon(*args, **kwargs): ...
    def set_icon_name(*args, **kwargs): ...
    def set_pixbuf(*args, **kwargs): ...
    

class PrintCompositor:
    parent_instance = ...
    priv = ...
    
    def draw_page(*args, **kwargs): ...
    def get_body_font_name(*args, **kwargs): ...
    def get_bottom_margin(*args, **kwargs): ...
    def get_buffer(*args, **kwargs): ...
    def get_footer_font_name(*args, **kwargs): ...
    def get_header_font_name(*args, **kwargs): ...
    def get_highlight_syntax(*args, **kwargs): ...
    def get_left_margin(*args, **kwargs): ...
    def get_line_numbers_font_name(*args, **kwargs): ...
    def get_n_pages(*args, **kwargs): ...
    def get_pagination_progress(*args, **kwargs): ...
    def get_print_footer(*args, **kwargs): ...
    def get_print_header(*args, **kwargs): ...
    def get_print_line_numbers(*args, **kwargs): ...
    def get_right_margin(*args, **kwargs): ...
    def get_tab_width(*args, **kwargs): ...
    def get_top_margin(*args, **kwargs): ...
    def get_wrap_mode(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def new_from_view(*args, **kwargs): ...
    def paginate(*args, **kwargs): ...
    def set_body_font_name(*args, **kwargs): ...
    def set_bottom_margin(*args, **kwargs): ...
    def set_footer_font_name(*args, **kwargs): ...
    def set_footer_format(*args, **kwargs): ...
    def set_header_font_name(*args, **kwargs): ...
    def set_header_format(*args, **kwargs): ...
    def set_highlight_syntax(*args, **kwargs): ...
    def set_left_margin(*args, **kwargs): ...
    def set_line_numbers_font_name(*args, **kwargs): ...
    def set_print_footer(*args, **kwargs): ...
    def set_print_header(*args, **kwargs): ...
    def set_print_line_numbers(*args, **kwargs): ...
    def set_right_margin(*args, **kwargs): ...
    def set_tab_width(*args, **kwargs): ...
    def set_top_margin(*args, **kwargs): ...
    def set_wrap_mode(*args, **kwargs): ...
    

class Region:
    parent_instance = ...
    
    def add_region(*args, **kwargs): ...
    def add_subregion(*args, **kwargs): ...
    def get_bounds(*args, **kwargs): ...
    def get_buffer(*args, **kwargs): ...
    def get_start_region_iter(*args, **kwargs): ...
    def intersect_region(*args, **kwargs): ...
    def intersect_subregion(*args, **kwargs): ...
    def is_empty(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def subtract_region(*args, **kwargs): ...
    def subtract_subregion(*args, **kwargs): ...
    def to_string(*args, **kwargs): ...
    

class RegionIter:
    dummy1 = ...
    dummy2 = ...
    dummy3 = ...
    
    def get_subregion(*args, **kwargs): ...
    def is_end(*args, **kwargs): ...
    def next(*args, **kwargs): ...
    

class SearchContext:
    parent = ...
    priv = ...
    
    def backward(*args, **kwargs): ...
    def backward_async(*args, **kwargs): ...
    def backward_finish(*args, **kwargs): ...
    def forward(*args, **kwargs): ...
    def forward_async(*args, **kwargs): ...
    def forward_finish(*args, **kwargs): ...
    def get_buffer(*args, **kwargs): ...
    def get_highlight(*args, **kwargs): ...
    def get_match_style(*args, **kwargs): ...
    def get_occurrence_position(*args, **kwargs): ...
    def get_occurrences_count(*args, **kwargs): ...
    def get_regex_error(*args, **kwargs): ...
    def get_settings(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def replace(*args, **kwargs): ...
    def replace_all(*args, **kwargs): ...
    def set_highlight(*args, **kwargs): ...
    def set_match_style(*args, **kwargs): ...
    

class SearchSettings:
    parent = ...
    priv = ...
    
    def get_at_word_boundaries(*args, **kwargs): ...
    def get_case_sensitive(*args, **kwargs): ...
    def get_regex_enabled(*args, **kwargs): ...
    def get_search_text(*args, **kwargs): ...
    def get_wrap_around(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def set_at_word_boundaries(*args, **kwargs): ...
    def set_case_sensitive(*args, **kwargs): ...
    def set_regex_enabled(*args, **kwargs): ...
    def set_search_text(*args, **kwargs): ...
    def set_wrap_around(*args, **kwargs): ...
    

class SpaceDrawer:
    parent = ...
    priv = ...
    
    def bind_matrix_setting(*args, **kwargs): ...
    def get_enable_matrix(*args, **kwargs): ...
    def get_matrix(*args, **kwargs): ...
    def get_types_for_locations(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def set_enable_matrix(*args, **kwargs): ...
    def set_matrix(*args, **kwargs): ...
    def set_types_for_locations(*args, **kwargs): ...
    

class Style:
    def apply(*args, **kwargs): ...
    def copy(*args, **kwargs): ...


class StyleScheme(GObject.Object):
    base = ...
    priv = ...
    
    def get_authors(*args, **kwargs): ...
    def get_description(*args, **kwargs): ...
    def get_filename(*args, **kwargs): ...
    def get_id(*args, **kwargs): ...
    def get_name(*args, **kwargs): ...
    def get_style(*args, **kwargs): ...
    

class StyleSchemeChooser:
    def get_style_scheme(*args, **kwargs): ...
    def set_style_scheme(*args, **kwargs): ...
    

class StyleSchemeChooserButton:
    parent = ...
    

class StyleSchemeChooserInterface:
    base_interface = ...
    get_style_scheme = ...
    padding = ...
    set_style_scheme = ...
    

class StyleSchemeChooserWidget:
    parent = ...
    
    def new(*args, **kwargs): ...
    

class StyleSchemeManager(GObject.Object):
    parent = ...
    priv = ...
    
    def append_search_path(*args, **kwargs): ...
    def force_rescan(*args, **kwargs): ...
    @classmethod
    def get_default(cls) -> StyleSchemeManager: ...
    def get_scheme(self, scheme_id: str) -> Optional[StyleScheme]: ...
    def get_scheme_ids(*args, **kwargs): ...
    def get_search_path(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def prepend_search_path(*args, **kwargs): ...
    def set_search_path(*args, **kwargs): ...
    

class Tag: ...

class UndoManager:
    def begin_not_undoable_action(*args, **kwargs): ...
    def can_redo(*args, **kwargs): ...
    def can_redo_changed(*args, **kwargs): ...
    def can_undo(*args, **kwargs): ...
    def can_undo_changed(*args, **kwargs): ...
    def end_not_undoable_action(*args, **kwargs): ...
    def redo(*args, **kwargs): ...
    def undo(*args, **kwargs): ...
    

class View(Gtk.TextView):
    parent = ...
    
    def get_auto_indent(*args, **kwargs): ...
    def get_buffer(self) -> Buffer: ...
    def get_background_pattern(*args, **kwargs): ...
    def get_completion(*args, **kwargs): ...
    def get_gutter(*args, **kwargs): ...
    def get_highlight_current_line(*args, **kwargs): ...
    def get_indent_on_tab(*args, **kwargs): ...
    def get_indent_width(*args, **kwargs): ...
    def get_insert_spaces_instead_of_tabs(*args, **kwargs): ...
    def get_mark_attributes(*args, **kwargs): ...
    def get_right_margin_position(*args, **kwargs): ...
    def get_show_line_marks(*args, **kwargs): ...
    def get_show_right_margin(*args, **kwargs): ...
    def get_smart_backspace(*args, **kwargs): ...
    def get_smart_home_end(*args, **kwargs): ...
    def get_space_drawer(*args, **kwargs): ...
    def get_tab_width(*args, **kwargs): ...
    def get_visual_column(*args, **kwargs): ...
    def indent_lines(*args, **kwargs): ...
    def set_auto_indent(*args, **kwargs): ...
    def set_background_pattern(*args, **kwargs): ...
    def set_highlight_current_line(*args, **kwargs): ...
    def set_indent_on_tab(*args, **kwargs): ...
    def set_indent_width(*args, **kwargs): ...
    def set_insert_spaces_instead_of_tabs(*args, **kwargs): ...
    def set_mark_attributes(*args, **kwargs): ...
    def set_right_margin_position(*args, **kwargs): ...
    def set_show_line_marks(*args, **kwargs): ...
    def set_show_line_numbers(self, show: bool) -> None: ...
    def set_show_right_margin(*args, **kwargs): ...
    def set_smart_backspace(*args, **kwargs): ...
    def set_smart_home_end(*args, **kwargs): ...
    def set_tab_width(*args, **kwargs): ...
    def unindent_lines(*args, **kwargs): ...
    
    def do_line_mark_activated(self, *args, **kwargs): ...
    def do_move_lines(self, *args, **kwargs): ...
    def do_move_words(self, *args, **kwargs): ...
    def do_redo(self, *args, **kwargs): ...
    def do_show_completion(self, *args, **kwargs): ...
    def do_undo(self, *args, **kwargs): ...
    

class CompletionActivation(GObject.GFlags):
    NONE = ...
    INTERACTIVE = ...
    USER_REQUESTED = ...

class FileSaverFlags(GObject.GFlags):
    NONE = ...
    IGNORE_INVALID_CHARS = ...
    IGNORE_MODIFICATION_TIME = ...
    CREATE_BACKUP = ...

class GutterRendererState(GObject.GFlags):
    NORMAL = ...
    CURSOR = ...
    PRELIT = ...
    SELECTED = ...

class SortFlags(GObject.GFlags):
    NONE = ...
    CASE_SENSITIVE = ...
    REVERSE_ORDER = ...
    REMOVE_DUPLICATES = ...

class SpaceLocationFlags(GObject.GFlags):
    NONE = ...
    LEADING = ...
    INSIDE_TEXT = ...
    TRAILING = ...
    ALL = ...

class SpaceTypeFlags(GObject.GFlags):
    NONE = ...
    SPACE = ...
    TAB = ...
    NEWLINE = ...
    NBSP = ...
    ALL = ...

class BackgroundPatternType(GObject.GEnum):
    NONE = ...
    GRID = ...

class BracketMatchType(GObject.GEnum):
    NONE = ...
    OUT_OF_RANGE = ...
    NOT_FOUND = ...
    FOUND = ...

class ChangeCaseType(GObject.GEnum):
    LOWER = ...
    UPPER = ...
    TOGGLE = ...
    TITLE = ...

class CompletionError(GObject.GEnum):
    ALREADY_BOUND = ...
    NOT_BOUND = ...
    quark = ...

class CompressionType(GObject.GEnum):
    NONE = ...
    GZIP = ...

class FileLoaderError(GObject.GEnum):
    TOO_BIG = ...
    ENCODING_AUTO_DETECTION_FAILED = ...
    CONVERSION_FALLBACK = ...
    quark = ...

class FileSaverError(GObject.GEnum):
    INVALID_CHARS = ...
    EXTERNALLY_MODIFIED = ...
    quark = ...

class GutterRendererAlignmentMode(GObject.GEnum):
    CELL = ...
    FIRST = ...
    LAST = ...

class NewlineType(GObject.GEnum):
    LF = ...
    CR = ...
    CR_LF = ...

class SmartHomeEndType(GObject.GEnum):
    DISABLED = ...
    BEFORE = ...
    AFTER = ...
    ALWAYS = ...

class ViewGutterPosition(GObject.GEnum):
    LINES = ...
    MARKS = ...




from typing import Any
from typing import Callable
from typing import TypeVar
from typing import Type

from enum import Flag
from enum import Enum

_T = TypeVar('_T')


G_MAXDOUBLE: float = ...
G_MAXFLOAT: float = ...
G_MAXINT: int = ...
G_MAXINT16: int = ...
G_MAXINT32: int = ...
G_MAXINT64: int = ...
G_MAXINT8: int = ...
G_MAXLONG: int = ...
G_MAXOFFSET: int = ...
G_MAXSHORT: int = ...
G_MAXSIZE: int = ...
G_MAXSSIZE: int = ...
G_MAXUINT: int = ...
G_MAXUINT16: int = ...
G_MAXUINT32: int = ...
G_MAXUINT64: int = ...
G_MAXUINT8: int = ...
G_MAXULONG: int = ...
G_MAXUSHORT: int = ...
G_MINDOUBLE: float = ...
G_MINFLOAT: float = ...
G_MININT: int = ...
G_MININT16: int = ...
G_MININT32: int = ...
G_MININT64: int = ...
G_MININT8: int = ...
G_MINLONG: int = ...
G_MINOFFSET: int = ...
G_MINSHORT: int = ...
G_MINSSIZE: int = ...
IO_ERR = ...
IO_FLAG_APPEND = ...
IO_FLAG_GET_MASK = ...
IO_FLAG_IS_READABLE = ...
IO_FLAG_IS_SEEKABLE = ...
IO_FLAG_IS_WRITEABLE = ...
IO_FLAG_MASK = ...
IO_FLAG_NONBLOCK = ...
IO_FLAG_SET_MASK = ...
IO_HUP = ...
IO_IN = ...
IO_NVAL = ...
IO_OUT = ...
IO_PRI = ...
IO_STATUS_AGAIN = ...
IO_STATUS_EOF = ...
IO_STATUS_ERROR = ...
IO_STATUS_NORMAL = ...
OPTION_ERROR_BAD_VALUE = ...
OPTION_ERROR_FAILED = ...
OPTION_ERROR_UNKNOWN_OPTION = ...
OPTION_FLAG_FILENAME = ...
OPTION_FLAG_HIDDEN = ...
OPTION_FLAG_IN_MAIN = ...
OPTION_FLAG_NOALIAS = ...
OPTION_FLAG_NO_ARG = ...
OPTION_FLAG_OPTIONAL_ARG = ...
OPTION_FLAG_REVERSE = ...
OPTION_REMAINING: str = ...
PARAM_CONSTRUCT = ...
PARAM_CONSTRUCT_ONLY = ...
PARAM_LAX_VALIDATION = ...
PARAM_MASK: int = ...
PARAM_READABLE = ...
PARAM_READWRITE = ...
PARAM_STATIC_STRINGS: int = ...
PARAM_USER_SHIFT: int = ...
PARAM_WRITABLE = ...
PRIORITY_DEFAULT = ...
PRIORITY_DEFAULT_IDLE: int = ...
PRIORITY_HIGH: int = ...
PRIORITY_HIGH_IDLE: int = ...
PRIORITY_LOW: int = ...
SIGNAL_ACTION = ...
SIGNAL_DETAILED = ...
SIGNAL_FLAGS_MASK: int = ...
SIGNAL_MATCH_MASK: int = ...
SIGNAL_NO_HOOKS = ...
SIGNAL_NO_RECURSE = ...
SIGNAL_RUN_CLEANUP = ...
SIGNAL_RUN_FIRST = ...
SIGNAL_RUN_LAST = ...
SPAWN_CHILD_INHERITS_STDIN = ...
SPAWN_DO_NOT_REAP_CHILD = ...
SPAWN_FILE_AND_ARGV_ZERO = ...
SPAWN_LEAVE_DESCRIPTORS_OPEN = ...
SPAWN_SEARCH_PATH = ...
SPAWN_STDERR_TO_DEV_NULL = ...
SPAWN_STDOUT_TO_DEV_NULL = ...
TYPE_BOOLEAN = ...
TYPE_BOXED = ...
TYPE_CHAR = ...
TYPE_DOUBLE = ...
TYPE_ENUM = ...
TYPE_FLAGS = ...
TYPE_FLAG_RESERVED_ID_BIT: int = ...
TYPE_FLOAT = ...
TYPE_FUNDAMENTAL_MAX: int = ...
TYPE_FUNDAMENTAL_SHIFT: int = ...
TYPE_GSTRING = ...
TYPE_GTYPE = ...
TYPE_INT = ...
TYPE_INT64 = ...
TYPE_INTERFACE = ...
TYPE_INVALID = ...
TYPE_LONG = ...
TYPE_NONE = ...
TYPE_OBJECT = ...
TYPE_PARAM = ...
TYPE_POINTER = ...
TYPE_PYOBJECT = ...
TYPE_RESERVED_BSE_FIRST: int = ...
TYPE_RESERVED_BSE_LAST: int = ...
TYPE_RESERVED_GLIB_FIRST: int = ...
TYPE_RESERVED_GLIB_LAST: int = ...
TYPE_RESERVED_USER_FIRST: int = ...
TYPE_STRING = ...
TYPE_STRV = ...
TYPE_UCHAR = ...
TYPE_UINT = ...
TYPE_UINT64 = ...
TYPE_ULONG = ...
TYPE_UNICHAR = ...
TYPE_VALUE = ...
TYPE_VARIANT = ...
VALUE_INTERNED_STRING: int = ...
VALUE_NOCOPY_CONTENTS: int = ...
features = ...
glib_version = ...
pygobject_version: tuple[int, int, int, int, int] = ...

def add_emission_hook(*args, **kwargs): ...
def boxed_copy(*args, **kwargs): ...
def boxed_free(*args, **kwargs): ...
def cclosure_marshal_BOOLEAN__BOXED_BOXED(*args, **kwargs): ...
def cclosure_marshal_BOOLEAN__FLAGS(*args, **kwargs): ...
def cclosure_marshal_STRING__OBJECT_POINTER(*args, **kwargs): ...
def cclosure_marshal_VOID__BOOLEAN(*args, **kwargs): ...
def cclosure_marshal_VOID__BOXED(*args, **kwargs): ...
def cclosure_marshal_VOID__CHAR(*args, **kwargs): ...
def cclosure_marshal_VOID__DOUBLE(*args, **kwargs): ...
def cclosure_marshal_VOID__ENUM(*args, **kwargs): ...
def cclosure_marshal_VOID__FLAGS(*args, **kwargs): ...
def cclosure_marshal_VOID__FLOAT(*args, **kwargs): ...
def cclosure_marshal_VOID__INT(*args, **kwargs): ...
def cclosure_marshal_VOID__LONG(*args, **kwargs): ...
def cclosure_marshal_VOID__OBJECT(*args, **kwargs): ...
def cclosure_marshal_VOID__PARAM(*args, **kwargs): ...
def cclosure_marshal_VOID__POINTER(*args, **kwargs): ...
def cclosure_marshal_VOID__STRING(*args, **kwargs): ...
def cclosure_marshal_VOID__UCHAR(*args, **kwargs): ...
def cclosure_marshal_VOID__UINT(*args, **kwargs): ...
def cclosure_marshal_VOID__UINT_POINTER(*args, **kwargs): ...
def cclosure_marshal_VOID__ULONG(*args, **kwargs): ...
def cclosure_marshal_VOID__VARIANT(*args, **kwargs): ...
def cclosure_marshal_VOID__VOID(*args, **kwargs): ...
def cclosure_marshal_generic(*args, **kwargs): ...
def child_watch_add(*args, **kwargs): ...
def clear_signal_handler(*args, **kwargs): ...
def enum_complete_type_info(*args, **kwargs): ...
def enum_get_value(*args, **kwargs): ...
def enum_get_value_by_name(*args, **kwargs): ...
def enum_get_value_by_nick(*args, **kwargs): ...
def enum_register_static(*args, **kwargs): ...
def enum_to_string(*args, **kwargs): ...
def filename_display_basename(*args, **kwargs): ...
def filename_display_name(*args, **kwargs): ...
def filename_from_utf8(*args, **kwargs): ...
def flags_complete_type_info(*args, **kwargs): ...
def flags_get_first_value(*args, **kwargs): ...
def flags_get_value_by_name(*args, **kwargs): ...
def flags_get_value_by_nick(*args, **kwargs): ...
def flags_register_static(*args, **kwargs): ...
def flags_to_string(*args, **kwargs): ...
def get_application_name(*args, **kwargs): ...
def get_current_time(*args, **kwargs): ...
def get_prgname(*args, **kwargs): ...
def gtype_get_type(*args, **kwargs): ...
def idle_add(*args, **kwargs): ...
def io_add_watch(*args, **kwargs): ...
def list_properties(*args, **kwargs): ...
def main_context_default(*args, **kwargs): ...
def main_depth(*args, **kwargs): ...
def markup_escape_text(*args, **kwargs): ...
def new(*args, **kwargs): ...
def param_spec_boolean(*args, **kwargs): ...
def param_spec_boxed(*args, **kwargs): ...
def param_spec_char(*args, **kwargs): ...
def param_spec_double(*args, **kwargs): ...
def param_spec_enum(*args, **kwargs): ...
def param_spec_flags(*args, **kwargs): ...
def param_spec_float(*args, **kwargs): ...
def param_spec_gtype(*args, **kwargs): ...
def param_spec_int(*args, **kwargs): ...
def param_spec_int64(*args, **kwargs): ...
def param_spec_long(*args, **kwargs): ...
def param_spec_object(*args, **kwargs): ...
def param_spec_param(*args, **kwargs): ...
def param_spec_pointer(*args, **kwargs): ...
def param_spec_string(*args, **kwargs): ...
def param_spec_uchar(*args, **kwargs): ...
def param_spec_uint(*args, **kwargs): ...
def param_spec_uint64(*args, **kwargs): ...
def param_spec_ulong(*args, **kwargs): ...
def param_spec_unichar(*args, **kwargs): ...
def param_spec_variant(*args, **kwargs): ...
def param_type_register_static(*args, **kwargs): ...
def param_value_convert(*args, **kwargs): ...
def param_value_defaults(*args, **kwargs): ...
def param_value_set_default(*args, **kwargs): ...
def param_value_validate(*args, **kwargs): ...
def param_values_cmp(*args, **kwargs): ...
def pointer_type_register_static(*args, **kwargs): ...
def remove_emission_hook(*args, **kwargs): ...
def set_application_name(*args, **kwargs): ...
def set_prgname(*args, **kwargs): ...
def signal_accumulator_first_wins(*args, **kwargs): ...
def signal_accumulator_true_handled(*args, **kwargs): ...
def signal_add_emission_hook(*args, **kwargs): ...
def signal_chain_from_overridden(*args, **kwargs): ...
def signal_connect_closure(*args, **kwargs): ...
def signal_connect_closure_by_id(*args, **kwargs): ...
def signal_emitv(*args, **kwargs): ...
def signal_get_invocation_hint(*args, **kwargs): ...
def signal_handler_block(*args, **kwargs): ...
def signal_handler_disconnect(*args, **kwargs): ...
def signal_handler_find(*args, **kwargs): ...
def signal_handler_is_connected(*args, **kwargs): ...
def signal_handler_unblock(*args, **kwargs): ...
def signal_handlers_block_matched(*args, **kwargs): ...
def signal_handlers_destroy(*args, **kwargs): ...
def signal_handlers_disconnect_matched(*args, **kwargs): ...
def signal_handlers_unblock_matched(*args, **kwargs): ...
def signal_has_handler_pending(*args, **kwargs): ...
def signal_is_valid_name(*args, **kwargs): ...
def signal_list_ids(*args, **kwargs): ...
def signal_list_names(*args, **kwargs): ...
def signal_lookup(*args, **kwargs): ...
def signal_name(*args, **kwargs): ...
def signal_new(*args, **kwargs): ...
def signal_override_class_closure(*args, **kwargs): ...
def signal_parse_name(*args, **kwargs): ...
def signal_query(*args, **kwargs): ...
def signal_remove_emission_hook(*args, **kwargs): ...
def signal_set_va_marshaller(*args, **kwargs): ...
def signal_stop_emission(*args, **kwargs): ...
def signal_stop_emission_by_name(*args, **kwargs): ...
def signal_type_cclosure_new(*args, **kwargs): ...
def source_remove(*args, **kwargs): ...
def source_set_closure(*args, **kwargs): ...
def source_set_dummy_callback(*args, **kwargs): ...
def spawn_async(*args, **kwargs): ...
def strdup_value_contents(*args, **kwargs): ...
def threads_init(*args, **kwargs): ...
def timeout_add(*args, **kwargs): ...
def timeout_add_seconds(*args, **kwargs): ...
def type_add_class_private(*args, **kwargs): ...
def type_add_instance_private(*args, **kwargs): ...
def type_add_interface_dynamic(*args, **kwargs): ...
def type_add_interface_static(*args, **kwargs): ...
def type_check_class_is_a(*args, **kwargs): ...
def type_check_instance(*args, **kwargs): ...
def type_check_instance_is_a(*args, **kwargs): ...
def type_check_instance_is_fundamentally_a(*args, **kwargs): ...
def type_check_is_value_type(*args, **kwargs): ...
def type_check_value(*args, **kwargs): ...
def type_check_value_holds(*args, **kwargs): ...
def type_children(*args, **kwargs): ...
def type_class_adjust_private_offset(*args, **kwargs): ...
def type_class_peek(*args, **kwargs): ...
def type_class_peek_static(*args, **kwargs): ...
def type_class_ref(*args, **kwargs): ...
def type_default_interface_peek(*args, **kwargs): ...
def type_default_interface_ref(*args, **kwargs): ...
def type_default_interface_unref(*args, **kwargs): ...
def type_depth(*args, **kwargs): ...
def type_ensure(*args, **kwargs): ...
def type_free_instance(*args, **kwargs): ...
def type_from_name(*args, **kwargs): ...
def type_fundamental(*args, **kwargs): ...
def type_fundamental_next(*args, **kwargs): ...
def type_get_instance_count(*args, **kwargs): ...
def type_get_plugin(*args, **kwargs): ...
def type_get_qdata(*args, **kwargs): ...
def type_get_type_registration_serial(*args, **kwargs): ...
def type_init(*args, **kwargs): ...
def type_init_with_debug_flags(*args, **kwargs): ...
def type_interface_add_prerequisite(*args, **kwargs): ...
def type_interface_get_plugin(*args, **kwargs): ...
def type_interface_instantiatable_prerequisite(*args, **kwargs): ...
def type_interface_peek(*args, **kwargs): ...
def type_interface_prerequisites(*args, **kwargs): ...
def type_interfaces(*args, **kwargs): ...
def type_is_a(*args, **kwargs): ...
def type_name(*args, **kwargs): ...
def type_name_from_class(*args, **kwargs): ...
def type_name_from_instance(*args, **kwargs): ...
def type_next_base(*args, **kwargs): ...
def type_parent(*args, **kwargs): ...
def type_qname(*args, **kwargs): ...
def type_query(*args, **kwargs): ...
def type_register(*args, **kwargs): ...
def type_register_dynamic(*args, **kwargs): ...
def type_register_fundamental(*args, **kwargs): ...
def type_register_static(*args, **kwargs): ...
def type_set_qdata(*args, **kwargs): ...
def type_test_flags(*args, **kwargs): ...
def uri_list_extract_uris(*args, **kwargs): ...
def value_type_compatible(*args, **kwargs): ...
def value_type_transformable(*args, **kwargs): ...


class Binding:
    def dup_source(*args, **kwargs): ...
    def dup_target(*args, **kwargs): ...
    def get_flags(*args, **kwargs): ...
    def get_source(*args, **kwargs): ...
    def get_source_property(*args, **kwargs): ...
    def get_target(*args, **kwargs): ...
    def get_target_property(*args, **kwargs): ...
    def unbind(*args, **kwargs): ...
    

class CClosure:
    callback = ...
    closure = ...
    
    def marshal_BOOLEAN__BOXED_BOXED(*args, **kwargs): ...
    def marshal_BOOLEAN__FLAGS(*args, **kwargs): ...
    def marshal_STRING__OBJECT_POINTER(*args, **kwargs): ...
    def marshal_VOID__BOOLEAN(*args, **kwargs): ...
    def marshal_VOID__BOXED(*args, **kwargs): ...
    def marshal_VOID__CHAR(*args, **kwargs): ...
    def marshal_VOID__DOUBLE(*args, **kwargs): ...
    def marshal_VOID__ENUM(*args, **kwargs): ...
    def marshal_VOID__FLAGS(*args, **kwargs): ...
    def marshal_VOID__FLOAT(*args, **kwargs): ...
    def marshal_VOID__INT(*args, **kwargs): ...
    def marshal_VOID__LONG(*args, **kwargs): ...
    def marshal_VOID__OBJECT(*args, **kwargs): ...
    def marshal_VOID__PARAM(*args, **kwargs): ...
    def marshal_VOID__POINTER(*args, **kwargs): ...
    def marshal_VOID__STRING(*args, **kwargs): ...
    def marshal_VOID__UCHAR(*args, **kwargs): ...
    def marshal_VOID__UINT(*args, **kwargs): ...
    def marshal_VOID__UINT_POINTER(*args, **kwargs): ...
    def marshal_VOID__ULONG(*args, **kwargs): ...
    def marshal_VOID__VARIANT(*args, **kwargs): ...
    def marshal_VOID__VOID(*args, **kwargs): ...
    def marshal_generic(*args, **kwargs): ...
    

class Closure:
    data = ...
    derivative_flag = ...
    floating = ...
    in_inotify = ...
    in_marshal = ...
    is_invalid = ...
    marshal = ...
    meta_marshal_nouse = ...
    n_fnotifiers = ...
    n_guards = ...
    n_inotifiers = ...
    notifiers = ...
    ref_count = ...
    
    def invalidate(*args, **kwargs): ...
    def invoke(*args, **kwargs): ...
    def new_object(*args, **kwargs): ...
    def new_simple(*args, **kwargs): ...
    def ref(*args, **kwargs): ...
    def sink(*args, **kwargs): ...
    def unref(*args, **kwargs): ...
    

class ClosureNotifyData:
    data = ...
    notify = ...
    

class EnumValue:
    value = ...
    value_name = ...
    value_nick = ...
    

class FlagsValue:
    value = ...
    value_name = ...
    value_nick = ...
    

class GBoxed:
    def copy(self, *args, **kwargs): ...
    

class GError:
    def copy(*args, **kwargs): ...
    def matches(*args, **kwargs): ...
    def new_literal(*args, **kwargs): ...
    

class GInterface: ...

class GObject:
    g_type_instance = ...
    props = ...
    qdata = ...
    ref_count = ...
    
    def bind_property_full(*args, **kwargs): ...
    def compat_control(*args, **kwargs): ...
    def connect_data(*args, **kwargs): ...
    def disconnect(*args, **kwargs): ...
    def emit_stop_by_name(*args, **kwargs): ...
    def find_property(*args, **kwargs): ...
    def force_floating(*args, **kwargs): ...
    def freeze_notify(*args, **kwargs): ...
    def get_data(*args, **kwargs): ...
    def get_qdata(*args, **kwargs): ...
    def getv(*args, **kwargs): ...
    def handler_block(*args, **kwargs): ...
    def handler_disconnect(*args, **kwargs): ...
    def handler_is_connected(*args, **kwargs): ...
    def handler_unblock(*args, **kwargs): ...
    def install_properties(*args, **kwargs): ...
    def install_property(*args, **kwargs): ...
    def interface_find_property(*args, **kwargs): ...
    def interface_install_property(*args, **kwargs): ...
    def interface_list_properties(*args, **kwargs): ...
    def is_floating(*args, **kwargs): ...
    def list_properties(*args, **kwargs): ...
    def newv(*args, **kwargs): ...
    def notify(*args, **kwargs): ...
    def notify_by_pspec(*args, **kwargs): ...
    def override_property(*args, **kwargs): ...
    def ref(*args, **kwargs): ...
    def ref_sink(*args, **kwargs): ...
    def replace_data(*args, **kwargs): ...
    def replace_qdata(*args, **kwargs): ...
    def run_dispose(*args, **kwargs): ...
    def set_data(*args, **kwargs): ...
    def steal_data(*args, **kwargs): ...
    def steal_qdata(*args, **kwargs): ...
    def stop_emission(*args, **kwargs): ...
    def stop_emission_by_name(*args, **kwargs): ...
    def thaw_notify(*args, **kwargs): ...
    def unref(*args, **kwargs): ...
    def watch_closure(*args, **kwargs): ...
    
    def bind_property(self, *args, **kwargs): ...
    def chain(self, *args, **kwargs): ...
    def connect(self, *args, **kwargs): ...
    def connect_after(self, *args, **kwargs): ...
    def connect_object(self, *args, **kwargs): ...
    def connect_object_after(self, *args, **kwargs): ...
    def disconnect_by_func(self, *args, **kwargs): ...
    def emit(self, *args, **kwargs): ...
    def get_properties(self, *args, **kwargs): ...
    def get_property(self, *args, **kwargs): ...
    def handler_block_by_func(self, *args, **kwargs): ...
    def handler_unblock_by_func(self, *args, **kwargs): ...
    def set_properties(self, *args, **kwargs): ...
    def set_property(self, *args, **kwargs): ...
    def weak_ref(self, *args, **kwargs): ...
    

class GObjectWeakRef:
    def unref(self, *args, **kwargs): ...
    

class GParamSpec: ...

class GPointer: ...

class GType:
    children = ...
    depth = ...
    fundamental = ...
    interfaces = ...
    name = ...
    parent = ...
    pytype = ...
    
    def from_name(*args, **kwargs): ...
    
    def has_value_table(self, *args, **kwargs): ...
    def is_a(self, *args, **kwargs): ...
    def is_abstract(self, *args, **kwargs): ...
    def is_classed(self, *args, **kwargs): ...
    def is_deep_derivable(self, *args, **kwargs): ...
    def is_derivable(self, *args, **kwargs): ...
    def is_instantiatable(self, *args, **kwargs): ...
    def is_interface(self, *args, **kwargs): ...
    def is_value_abstract(self, *args, **kwargs): ...
    def is_value_type(self, *args, **kwargs): ...
    

class Idle:
    callback_data = ...
    callback_funcs = ...
    can_recurse = ...
    context = ...
    flags = ...
    name = ...
    next = ...
    poll_fds = ...
    prev = ...
    priority = ...
    priv = ...
    ref_count = ...
    source_funcs = ...
    source_id = ...
    
    def add_child_source(*args, **kwargs): ...
    def add_poll(*args, **kwargs): ...
    def add_unix_fd(*args, **kwargs): ...
    def attach(*args, **kwargs): ...
    def destroy(*args, **kwargs): ...
    def get_can_recurse(*args, **kwargs): ...
    def get_context(*args, **kwargs): ...
    def get_current_time(*args, **kwargs): ...
    def get_id(*args, **kwargs): ...
    def get_name(*args, **kwargs): ...
    def get_priority(*args, **kwargs): ...
    def get_ready_time(*args, **kwargs): ...
    def get_time(*args, **kwargs): ...
    def is_destroyed(*args, **kwargs): ...
    def modify_unix_fd(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def query_unix_fd(*args, **kwargs): ...
    def ref(*args, **kwargs): ...
    def remove(*args, **kwargs): ...
    def remove_by_funcs_user_data(*args, **kwargs): ...
    def remove_by_user_data(*args, **kwargs): ...
    def remove_child_source(*args, **kwargs): ...
    def remove_poll(*args, **kwargs): ...
    def remove_unix_fd(*args, **kwargs): ...
    def set_callback(*args, **kwargs): ...
    def set_callback_indirect(*args, **kwargs): ...
    def set_can_recurse(*args, **kwargs): ...
    def set_funcs(*args, **kwargs): ...
    def set_name(*args, **kwargs): ...
    def set_name_by_id(*args, **kwargs): ...
    def set_priority(*args, **kwargs): ...
    def set_ready_time(*args, **kwargs): ...
    def unref(*args, **kwargs): ...
    

class InitiallyUnowned(Object): ...

class InterfaceInfo:
    interface_data = ...
    interface_finalize = ...
    interface_init = ...
    

class MainContext:
    def acquire(*args, **kwargs): ...
    def add_poll(*args, **kwargs): ...
    def check(*args, **kwargs): ...
    def default(*args, **kwargs): ...
    def dispatch(*args, **kwargs): ...
    def find_source_by_funcs_user_data(*args, **kwargs): ...
    def find_source_by_id(*args, **kwargs): ...
    def find_source_by_user_data(*args, **kwargs): ...
    def get_thread_default(*args, **kwargs): ...
    def invoke_full(*args, **kwargs): ...
    def is_owner(*args, **kwargs): ...
    def iteration(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def pending(*args, **kwargs): ...
    def pop_thread_default(*args, **kwargs): ...
    def prepare(*args, **kwargs): ...
    def push_thread_default(*args, **kwargs): ...
    def query(*args, **kwargs): ...
    def ref(*args, **kwargs): ...
    def ref_thread_default(*args, **kwargs): ...
    def release(*args, **kwargs): ...
    def remove_poll(*args, **kwargs): ...
    def unref(*args, **kwargs): ...
    def wait(*args, **kwargs): ...
    def wakeup(*args, **kwargs): ...
    

class MainLoop:
    def get_context(*args, **kwargs): ...
    def is_running(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def quit(*args, **kwargs): ...
    def ref(*args, **kwargs): ...
    def run(*args, **kwargs): ...
    def unref(*args, **kwargs): ...
    

class Object:
    g_type_instance = ...
    props = ...
    qdata = ...
    ref_count = ...

    def bind_property_full(*args, **kwargs): ...
    def compat_control(*args, **kwargs): ...
    def connect_data(*args, **kwargs): ...
    def disconnect(self, id: int) -> None: ...
    def emit_stop_by_name(*args, **kwargs): ...
    def find_property(*args, **kwargs): ...
    def force_floating(*args, **kwargs): ...
    def freeze_notify(*args, **kwargs): ...
    def get_data(*args, **kwargs): ...
    def get_qdata(*args, **kwargs): ...
    def getv(*args, **kwargs): ...
    def handler_block(*args, **kwargs): ...
    def handler_disconnect(*args, **kwargs): ...
    def handler_is_connected(self, id: int) -> bool: ...
    def handler_unblock(*args, **kwargs): ...
    def install_properties(*args, **kwargs): ...
    def install_property(*args, **kwargs): ...
    def interface_find_property(*args, **kwargs): ...
    def interface_install_property(*args, **kwargs): ...
    def interface_list_properties(*args, **kwargs): ...
    def is_floating(*args, **kwargs): ...
    def list_properties(*args, **kwargs): ...
    def newv(*args, **kwargs): ...
    def notify(*args, **kwargs): ...
    def notify_by_pspec(*args, **kwargs): ...
    def override_property(*args, **kwargs): ...
    def ref(*args, **kwargs): ...
    def ref_sink(*args, **kwargs): ...
    def replace_data(*args, **kwargs): ...
    def replace_qdata(*args, **kwargs): ...
    def run_dispose(*args, **kwargs): ...
    def set_data(*args, **kwargs): ...
    def steal_data(*args, **kwargs): ...
    def steal_qdata(*args, **kwargs): ...
    def stop_emission(*args, **kwargs): ...
    def stop_emission_by_name(self, detailed_signal: str) -> None: ...
    def thaw_notify(*args, **kwargs): ...
    def unref(*args, **kwargs): ...
    def watch_closure(*args, **kwargs): ...
    
    def bind_property(self, *args, **kwargs): ...
    def chain(self, *args, **kwargs): ...
    def connect(self, detailed_signal: str, handler: Callable[..., Any], *args: Any) -> int: ...
    def connect_after(self, detailed_signal: str, handler: Callable[..., Any], *args: Any) -> int: ...
    def connect_object(self, *args, **kwargs): ...
    def connect_object_after(self, *args, **kwargs): ...
    def disconnect_by_func(self, *args, **kwargs): ...
    def emit(self, signal_name: str, *args: Any) -> None: ...
    def get_properties(self, *args, **kwargs): ...
    def get_property(self, property_name: str) -> Any: ...
    def handler_block_by_func(self, *args, **kwargs): ...
    def handler_unblock_by_func(self, *args, **kwargs): ...
    def set_properties(self, *args, **kwargs): ...
    def set_property(self, property_name: str, value: object) -> None: ...
    def weak_ref(self, *args, **kwargs): ...
    

class ObjectConstructParam:
    pspec = ...
    value = ...
    

class OptionContext:
    def add_group(self, *args, **kwargs): ...
    def get_help_enabled(self, *args, **kwargs): ...
    def get_ignore_unknown_options(self, *args, **kwargs): ...
    def get_main_group(self, *args, **kwargs): ...
    def parse(self, *args, **kwargs): ...
    def set_help_enabled(self, *args, **kwargs): ...
    def set_ignore_unknown_options(self, *args, **kwargs): ...
    def set_main_group(self, *args, **kwargs): ...
    

class OptionGroup:
    def add_entries(self, *args, **kwargs): ...
    def set_translation_domain(self, *args, **kwargs): ...
    

class ParamSpec:
    _blurb = ...
    _nick = ...
    flags = ...
    g_type_instance = ...
    name = ...
    owner_type = ...
    param_id = ...
    qdata = ...
    ref_count = ...
    value_type = ...
    
    def get_blurb(*args, **kwargs): ...
    def get_default_value(*args, **kwargs): ...
    def get_name(*args, **kwargs): ...
    def get_name_quark(*args, **kwargs): ...
    def get_nick(*args, **kwargs): ...
    def get_qdata(*args, **kwargs): ...
    def get_redirect_target(*args, **kwargs): ...
    def is_valid_name(*args, **kwargs): ...
    def set_qdata(*args, **kwargs): ...
    def sink(*args, **kwargs): ...
    def steal_qdata(*args, **kwargs): ...
    
    def do_finalize(self, *args, **kwargs): ...
    def do_value_set_default(self, *args, **kwargs): ...
    def do_value_validate(self, *args, **kwargs): ...
    def do_values_cmp(self, *args, **kwargs): ...
    

class ParamSpecBoolean:
    default_value = ...
    parent_instance = ...
    

class ParamSpecBoxed:
    parent_instance = ...
    

class ParamSpecChar:
    default_value = ...
    maximum = ...
    minimum = ...
    parent_instance = ...
    

class ParamSpecDouble:
    default_value = ...
    epsilon = ...
    maximum = ...
    minimum = ...
    parent_instance = ...
    

class ParamSpecEnum:
    default_value = ...
    enum_class = ...
    parent_instance = ...
    

class ParamSpecFlags:
    default_value = ...
    flags_class = ...
    parent_instance = ...
    

class ParamSpecFloat:
    default_value = ...
    epsilon = ...
    maximum = ...
    minimum = ...
    parent_instance = ...
    

class ParamSpecGType:
    is_a_type = ...
    parent_instance = ...
    

class ParamSpecInt:
    default_value = ...
    maximum = ...
    minimum = ...
    parent_instance = ...
    

class ParamSpecInt64:
    default_value = ...
    maximum = ...
    minimum = ...
    parent_instance = ...
    

class ParamSpecLong:
    default_value = ...
    maximum = ...
    minimum = ...
    parent_instance = ...
    

class ParamSpecObject:
    parent_instance = ...
    

class ParamSpecOverride:
    overridden = ...
    parent_instance = ...
    

class ParamSpecParam:
    parent_instance = ...
    

class ParamSpecPointer:
    parent_instance = ...
    

class ParamSpecPool:
    def insert(*args, **kwargs): ...
    def list(*args, **kwargs): ...
    def list_owned(*args, **kwargs): ...
    def lookup(*args, **kwargs): ...
    def remove(*args, **kwargs): ...
    

class ParamSpecString:
    cset_first = ...
    cset_nth = ...
    default_value = ...
    ensure_non_null = ...
    null_fold_if_empty = ...
    parent_instance = ...
    substitutor = ...
    

class ParamSpecTypeInfo:
    finalize = ...
    instance_init = ...
    instance_size = ...
    n_preallocs = ...
    value_set_default = ...
    value_type = ...
    value_validate = ...
    values_cmp = ...
    

class ParamSpecUChar:
    default_value = ...
    maximum = ...
    minimum = ...
    parent_instance = ...
    

class ParamSpecUInt:
    default_value = ...
    maximum = ...
    minimum = ...
    parent_instance = ...
    

class ParamSpecUInt64:
    default_value = ...
    maximum = ...
    minimum = ...
    parent_instance = ...
    

class ParamSpecULong:
    default_value = ...
    maximum = ...
    minimum = ...
    parent_instance = ...
    

class ParamSpecUnichar:
    default_value = ...
    parent_instance = ...
    

class ParamSpecValueArray:
    element_spec = ...
    fixed_n_elements = ...
    parent_instance = ...
    

class ParamSpecVariant:
    default_value = ...
    padding = ...
    parent_instance = ...
    type = ...
    

class Parameter:
    name = ...
    value = ...
    

class Pid:
    denominator = ...
    imag = ...
    numerator = ...
    real = ...
    
    def from_bytes(*args, **kwargs): ...
    
    def as_integer_ratio(self, *args, **kwargs): ...
    def bit_length(self, *args, **kwargs): ...
    def close(self, *args, **kwargs): ...
    def conjugate(self, *args, **kwargs): ...
    def to_bytes(self, *args, **kwargs): ...
    

class PollFD:
    events = ...
    fd = ...
    revents = ...
    

class Property:
    _default_lookup = ...
    _max_value_lookup = ...
    _min_value_lookup = ...
    _type_from_pytype_lookup = ...
    
    def get_pspec_args(*args, **kwargs): ...
    def getter(*args, **kwargs): ...
    def setter(*args, **kwargs): ...
    

class Signal:
    def copy(*args, **kwargs): ...
    def get_signal_args(*args, **kwargs): ...
    def maketrans(*args, **kwargs): ...
    
    def capitalize(self, *args, **kwargs): ...
    def casefold(self, *args, **kwargs): ...
    def center(self, *args, **kwargs): ...
    def count(self, *args, **kwargs): ...
    def encode(self, *args, **kwargs): ...
    def endswith(self, *args, **kwargs): ...
    def expandtabs(self, *args, **kwargs): ...
    def find(self, *args, **kwargs): ...
    def format(self, *args, **kwargs): ...
    def format_map(self, *args, **kwargs): ...
    def index(self, *args, **kwargs): ...
    def isalnum(self, *args, **kwargs): ...
    def isalpha(self, *args, **kwargs): ...
    def isascii(self, *args, **kwargs): ...
    def isdecimal(self, *args, **kwargs): ...
    def isdigit(self, *args, **kwargs): ...
    def isidentifier(self, *args, **kwargs): ...
    def islower(self, *args, **kwargs): ...
    def isnumeric(self, *args, **kwargs): ...
    def isprintable(self, *args, **kwargs): ...
    def isspace(self, *args, **kwargs): ...
    def istitle(self, *args, **kwargs): ...
    def isupper(self, *args, **kwargs): ...
    def join(self, *args, **kwargs): ...
    def ljust(self, *args, **kwargs): ...
    def lower(self, *args, **kwargs): ...
    def lstrip(self, *args, **kwargs): ...
    def partition(self, *args, **kwargs): ...
    def removeprefix(self, *args, **kwargs): ...
    def removesuffix(self, *args, **kwargs): ...
    def replace(self, *args, **kwargs): ...
    def rfind(self, *args, **kwargs): ...
    def rindex(self, *args, **kwargs): ...
    def rjust(self, *args, **kwargs): ...
    def rpartition(self, *args, **kwargs): ...
    def rsplit(self, *args, **kwargs): ...
    def rstrip(self, *args, **kwargs): ...
    def split(self, *args, **kwargs): ...
    def splitlines(self, *args, **kwargs): ...
    def startswith(self, *args, **kwargs): ...
    def strip(self, *args, **kwargs): ...
    def swapcase(self, *args, **kwargs): ...
    def title(self, *args, **kwargs): ...
    def translate(self, *args, **kwargs): ...
    def upper(self, *args, **kwargs): ...
    def zfill(self, *args, **kwargs): ...
    
    class BoundSignal:
        def connect(*args, **kwargs): ...
        def connect_detailed(*args, **kwargs): ...
        def disconnect(*args, **kwargs): ...
        def emit(*args, **kwargs): ...
        def maketrans(*args, **kwargs): ...
        
        def capitalize(self, *args, **kwargs): ...
        def casefold(self, *args, **kwargs): ...
        def center(self, *args, **kwargs): ...
        def count(self, *args, **kwargs): ...
        def encode(self, *args, **kwargs): ...
        def endswith(self, *args, **kwargs): ...
        def expandtabs(self, *args, **kwargs): ...
        def find(self, *args, **kwargs): ...
        def format(self, *args, **kwargs): ...
        def format_map(self, *args, **kwargs): ...
        def index(self, *args, **kwargs): ...
        def isalnum(self, *args, **kwargs): ...
        def isalpha(self, *args, **kwargs): ...
        def isascii(self, *args, **kwargs): ...
        def isdecimal(self, *args, **kwargs): ...
        def isdigit(self, *args, **kwargs): ...
        def isidentifier(self, *args, **kwargs): ...
        def islower(self, *args, **kwargs): ...
        def isnumeric(self, *args, **kwargs): ...
        def isprintable(self, *args, **kwargs): ...
        def isspace(self, *args, **kwargs): ...
        def istitle(self, *args, **kwargs): ...
        def isupper(self, *args, **kwargs): ...
        def join(self, *args, **kwargs): ...
        def ljust(self, *args, **kwargs): ...
        def lower(self, *args, **kwargs): ...
        def lstrip(self, *args, **kwargs): ...
        def partition(self, *args, **kwargs): ...
        def removeprefix(self, *args, **kwargs): ...
        def removesuffix(self, *args, **kwargs): ...
        def replace(self, *args, **kwargs): ...
        def rfind(self, *args, **kwargs): ...
        def rindex(self, *args, **kwargs): ...
        def rjust(self, *args, **kwargs): ...
        def rpartition(self, *args, **kwargs): ...
        def rsplit(self, *args, **kwargs): ...
        def rstrip(self, *args, **kwargs): ...
        def split(self, *args, **kwargs): ...
        def splitlines(self, *args, **kwargs): ...
        def startswith(self, *args, **kwargs): ...
        def strip(self, *args, **kwargs): ...
        def swapcase(self, *args, **kwargs): ...
        def title(self, *args, **kwargs): ...
        def translate(self, *args, **kwargs): ...
        def upper(self, *args, **kwargs): ...
        def zfill(self, *args, **kwargs): ...
        
    

class SignalInvocationHint:
    detail = ...
    run_type = ...
    signal_id = ...
    

class SignalOverride:
    def copy(*args, **kwargs): ...
    def get_signal_args(*args, **kwargs): ...
    def maketrans(*args, **kwargs): ...
    
    def capitalize(self, *args, **kwargs): ...
    def casefold(self, *args, **kwargs): ...
    def center(self, *args, **kwargs): ...
    def count(self, *args, **kwargs): ...
    def encode(self, *args, **kwargs): ...
    def endswith(self, *args, **kwargs): ...
    def expandtabs(self, *args, **kwargs): ...
    def find(self, *args, **kwargs): ...
    def format(self, *args, **kwargs): ...
    def format_map(self, *args, **kwargs): ...
    def index(self, *args, **kwargs): ...
    def isalnum(self, *args, **kwargs): ...
    def isalpha(self, *args, **kwargs): ...
    def isascii(self, *args, **kwargs): ...
    def isdecimal(self, *args, **kwargs): ...
    def isdigit(self, *args, **kwargs): ...
    def isidentifier(self, *args, **kwargs): ...
    def islower(self, *args, **kwargs): ...
    def isnumeric(self, *args, **kwargs): ...
    def isprintable(self, *args, **kwargs): ...
    def isspace(self, *args, **kwargs): ...
    def istitle(self, *args, **kwargs): ...
    def isupper(self, *args, **kwargs): ...
    def join(self, *args, **kwargs): ...
    def ljust(self, *args, **kwargs): ...
    def lower(self, *args, **kwargs): ...
    def lstrip(self, *args, **kwargs): ...
    def partition(self, *args, **kwargs): ...
    def removeprefix(self, *args, **kwargs): ...
    def removesuffix(self, *args, **kwargs): ...
    def replace(self, *args, **kwargs): ...
    def rfind(self, *args, **kwargs): ...
    def rindex(self, *args, **kwargs): ...
    def rjust(self, *args, **kwargs): ...
    def rpartition(self, *args, **kwargs): ...
    def rsplit(self, *args, **kwargs): ...
    def rstrip(self, *args, **kwargs): ...
    def split(self, *args, **kwargs): ...
    def splitlines(self, *args, **kwargs): ...
    def startswith(self, *args, **kwargs): ...
    def strip(self, *args, **kwargs): ...
    def swapcase(self, *args, **kwargs): ...
    def title(self, *args, **kwargs): ...
    def translate(self, *args, **kwargs): ...
    def upper(self, *args, **kwargs): ...
    def zfill(self, *args, **kwargs): ...
    
    class BoundSignal:
        def connect(*args, **kwargs): ...
        def connect_detailed(*args, **kwargs): ...
        def disconnect(*args, **kwargs): ...
        def emit(*args, **kwargs): ...
        def maketrans(*args, **kwargs): ...
        
        def capitalize(self, *args, **kwargs): ...
        def casefold(self, *args, **kwargs): ...
        def center(self, *args, **kwargs): ...
        def count(self, *args, **kwargs): ...
        def encode(self, *args, **kwargs): ...
        def endswith(self, *args, **kwargs): ...
        def expandtabs(self, *args, **kwargs): ...
        def find(self, *args, **kwargs): ...
        def format(self, *args, **kwargs): ...
        def format_map(self, *args, **kwargs): ...
        def index(self, *args, **kwargs): ...
        def isalnum(self, *args, **kwargs): ...
        def isalpha(self, *args, **kwargs): ...
        def isascii(self, *args, **kwargs): ...
        def isdecimal(self, *args, **kwargs): ...
        def isdigit(self, *args, **kwargs): ...
        def isidentifier(self, *args, **kwargs): ...
        def islower(self, *args, **kwargs): ...
        def isnumeric(self, *args, **kwargs): ...
        def isprintable(self, *args, **kwargs): ...
        def isspace(self, *args, **kwargs): ...
        def istitle(self, *args, **kwargs): ...
        def isupper(self, *args, **kwargs): ...
        def join(self, *args, **kwargs): ...
        def ljust(self, *args, **kwargs): ...
        def lower(self, *args, **kwargs): ...
        def lstrip(self, *args, **kwargs): ...
        def partition(self, *args, **kwargs): ...
        def removeprefix(self, *args, **kwargs): ...
        def removesuffix(self, *args, **kwargs): ...
        def replace(self, *args, **kwargs): ...
        def rfind(self, *args, **kwargs): ...
        def rindex(self, *args, **kwargs): ...
        def rjust(self, *args, **kwargs): ...
        def rpartition(self, *args, **kwargs): ...
        def rsplit(self, *args, **kwargs): ...
        def rstrip(self, *args, **kwargs): ...
        def split(self, *args, **kwargs): ...
        def splitlines(self, *args, **kwargs): ...
        def startswith(self, *args, **kwargs): ...
        def strip(self, *args, **kwargs): ...
        def swapcase(self, *args, **kwargs): ...
        def title(self, *args, **kwargs): ...
        def translate(self, *args, **kwargs): ...
        def upper(self, *args, **kwargs): ...
        def zfill(self, *args, **kwargs): ...
        
    

class SignalQuery:
    itype = ...
    n_params = ...
    param_types = ...
    return_type = ...
    signal_flags = ...
    signal_id = ...
    signal_name = ...
    

class Source:
    callback_data = ...
    callback_funcs = ...
    can_recurse = ...
    context = ...
    flags = ...
    name = ...
    next = ...
    poll_fds = ...
    prev = ...
    priority = ...
    priv = ...
    ref_count = ...
    source_funcs = ...
    source_id = ...
    
    def add_child_source(*args, **kwargs): ...
    def add_poll(*args, **kwargs): ...
    def add_unix_fd(*args, **kwargs): ...
    def attach(*args, **kwargs): ...
    def destroy(*args, **kwargs): ...
    def get_can_recurse(*args, **kwargs): ...
    def get_context(*args, **kwargs): ...
    def get_current_time(*args, **kwargs): ...
    def get_id(*args, **kwargs): ...
    def get_name(*args, **kwargs): ...
    def get_priority(*args, **kwargs): ...
    def get_ready_time(*args, **kwargs): ...
    def get_time(*args, **kwargs): ...
    def is_destroyed(*args, **kwargs): ...
    def modify_unix_fd(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def query_unix_fd(*args, **kwargs): ...
    def ref(*args, **kwargs): ...
    def remove(*args, **kwargs): ...
    def remove_by_funcs_user_data(*args, **kwargs): ...
    def remove_by_user_data(*args, **kwargs): ...
    def remove_child_source(*args, **kwargs): ...
    def remove_poll(*args, **kwargs): ...
    def remove_unix_fd(*args, **kwargs): ...
    def set_callback(*args, **kwargs): ...
    def set_callback_indirect(*args, **kwargs): ...
    def set_can_recurse(*args, **kwargs): ...
    def set_funcs(*args, **kwargs): ...
    def set_name(*args, **kwargs): ...
    def set_name_by_id(*args, **kwargs): ...
    def set_priority(*args, **kwargs): ...
    def set_ready_time(*args, **kwargs): ...
    def unref(*args, **kwargs): ...
    

class Timeout:
    callback_data = ...
    callback_funcs = ...
    can_recurse = ...
    context = ...
    flags = ...
    name = ...
    next = ...
    poll_fds = ...
    prev = ...
    priority = ...
    priv = ...
    ref_count = ...
    source_funcs = ...
    source_id = ...
    
    def add_child_source(*args, **kwargs): ...
    def add_poll(*args, **kwargs): ...
    def add_unix_fd(*args, **kwargs): ...
    def attach(*args, **kwargs): ...
    def destroy(*args, **kwargs): ...
    def get_can_recurse(*args, **kwargs): ...
    def get_context(*args, **kwargs): ...
    def get_current_time(*args, **kwargs): ...
    def get_id(*args, **kwargs): ...
    def get_name(*args, **kwargs): ...
    def get_priority(*args, **kwargs): ...
    def get_ready_time(*args, **kwargs): ...
    def get_time(*args, **kwargs): ...
    def is_destroyed(*args, **kwargs): ...
    def modify_unix_fd(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def query_unix_fd(*args, **kwargs): ...
    def ref(*args, **kwargs): ...
    def remove(*args, **kwargs): ...
    def remove_by_funcs_user_data(*args, **kwargs): ...
    def remove_by_user_data(*args, **kwargs): ...
    def remove_child_source(*args, **kwargs): ...
    def remove_poll(*args, **kwargs): ...
    def remove_unix_fd(*args, **kwargs): ...
    def set_callback(*args, **kwargs): ...
    def set_callback_indirect(*args, **kwargs): ...
    def set_can_recurse(*args, **kwargs): ...
    def set_funcs(*args, **kwargs): ...
    def set_name(*args, **kwargs): ...
    def set_name_by_id(*args, **kwargs): ...
    def set_priority(*args, **kwargs): ...
    def set_ready_time(*args, **kwargs): ...
    def unref(*args, **kwargs): ...
    

class TypeCValue: ...

class TypeFundamentalInfo:
    type_flags = ...
    

class TypeInfo:
    base_finalize = ...
    base_init = ...
    class_data = ...
    class_finalize = ...
    class_init = ...
    class_size = ...
    instance_init = ...
    instance_size = ...
    n_preallocs = ...
    value_table = ...
    

class TypeInstance:
    g_class = ...
    
    def get_private(*args, **kwargs): ...
    

class TypeInterface:
    g_instance_type = ...
    g_type = ...
    
    def add_prerequisite(*args, **kwargs): ...
    def get_plugin(*args, **kwargs): ...
    def instantiatable_prerequisite(*args, **kwargs): ...
    def peek(*args, **kwargs): ...
    def peek_parent(*args, **kwargs): ...
    def prerequisites(*args, **kwargs): ...
    

class TypeModule:
    interface_infos = ...
    name = ...
    parent_instance = ...
    type_infos = ...
    use_count = ...
    
    def add_interface(*args, **kwargs): ...
    def register_enum(*args, **kwargs): ...
    def register_flags(*args, **kwargs): ...
    def register_type(*args, **kwargs): ...
    def set_name(*args, **kwargs): ...
    
    def do_load(self, *args, **kwargs): ...
    def do_unload(self, *args, **kwargs): ...
    

class TypePlugin:
    def complete_interface_info(*args, **kwargs): ...
    def complete_type_info(*args, **kwargs): ...
    def unuse(*args, **kwargs): ...
    def use(*args, **kwargs): ...
    

class TypeQuery:
    class_size = ...
    instance_size = ...
    type = ...
    type_name = ...
    

class TypeValueTable:
    collect_format = ...
    collect_value = ...
    lcopy_format = ...
    lcopy_value = ...
    value_copy = ...
    value_free = ...
    value_init = ...
    value_peek_pointer = ...
    

class Value:
    _Value__g_type = ...
    data = ...
    g_type = ...
    
    def dup_object(*args, **kwargs): ...
    def dup_string(*args, **kwargs): ...
    def dup_variant(*args, **kwargs): ...
    def fits_pointer(*args, **kwargs): ...
    def get_boolean(*args, **kwargs): ...
    def get_boxed(*args, **kwargs): ...
    def get_char(*args, **kwargs): ...
    def get_double(*args, **kwargs): ...
    def get_enum(*args, **kwargs): ...
    def get_flags(*args, **kwargs): ...
    def get_float(*args, **kwargs): ...
    def get_gtype(*args, **kwargs): ...
    def get_int(*args, **kwargs): ...
    def get_int64(*args, **kwargs): ...
    def get_long(*args, **kwargs): ...
    def get_object(*args, **kwargs): ...
    def get_param(*args, **kwargs): ...
    def get_pointer(*args, **kwargs): ...
    def get_schar(*args, **kwargs): ...
    def get_string(*args, **kwargs): ...
    def get_uchar(*args, **kwargs): ...
    def get_uint(*args, **kwargs): ...
    def get_uint64(*args, **kwargs): ...
    def get_ulong(*args, **kwargs): ...
    def get_value(*args, **kwargs): ...
    def get_variant(*args, **kwargs): ...
    def init(*args, **kwargs): ...
    def init_from_instance(*args, **kwargs): ...
    def peek_pointer(*args, **kwargs): ...
    def reset(*args, **kwargs): ...
    def set_boolean(*args, **kwargs): ...
    def set_boxed(*args, **kwargs): ...
    def set_boxed_take_ownership(*args, **kwargs): ...
    def set_char(*args, **kwargs): ...
    def set_double(*args, **kwargs): ...
    def set_enum(*args, **kwargs): ...
    def set_flags(*args, **kwargs): ...
    def set_float(*args, **kwargs): ...
    def set_gtype(*args, **kwargs): ...
    def set_instance(*args, **kwargs): ...
    def set_int(*args, **kwargs): ...
    def set_int64(*args, **kwargs): ...
    def set_interned_string(*args, **kwargs): ...
    def set_long(*args, **kwargs): ...
    def set_object(*args, **kwargs): ...
    def set_param(*args, **kwargs): ...
    def set_pointer(*args, **kwargs): ...
    def set_schar(*args, **kwargs): ...
    def set_static_boxed(*args, **kwargs): ...
    def set_static_string(*args, **kwargs): ...
    def set_string(*args, **kwargs): ...
    def set_string_take_ownership(*args, **kwargs): ...
    def set_uchar(*args, **kwargs): ...
    def set_uint(*args, **kwargs): ...
    def set_uint64(*args, **kwargs): ...
    def set_ulong(*args, **kwargs): ...
    def set_value(*args, **kwargs): ...
    def set_variant(*args, **kwargs): ...
    def take_boxed(*args, **kwargs): ...
    def take_string(*args, **kwargs): ...
    def take_variant(*args, **kwargs): ...
    def transform(*args, **kwargs): ...
    def type_compatible(*args, **kwargs): ...
    def type_transformable(*args, **kwargs): ...
    def unset(*args, **kwargs): ...
    

class ValueArray:
    n_prealloced = ...
    n_values = ...
    values = ...
    
    def append(*args, **kwargs): ...
    def get_nth(*args, **kwargs): ...
    def insert(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def prepend(*args, **kwargs): ...
    def remove(*args, **kwargs): ...
    def sort(*args, **kwargs): ...
    

class Warning:
    args = ...
    
    def with_traceback(self, *args, **kwargs): ...
    

class WeakRef: ...


# IntFlag is close enough to whatever GFlags does
class GFlags(int, Flag):
    __gtype__: GType
    first_value_name: str
    first_value_nick: str
    value_names: list[str]
    value_nicks: list[str]

    def __new__(cls: Type[_T], value: int | _T) -> _T: ...
    def __or__(self: _T, other: int | _T) -> _T: ...
    def __and__(self: _T, other: int | _T) -> _T: ...
    def __xor__(self: _T, other: int | _T) -> _T: ...
    def __ror__(self: _T, n: int | _T) -> _T: ...
    def __rand__(self: _T, n: int | _T) -> _T: ...
    def __rxor__(self: _T, n: int | _T) -> _T: ...

# IntEnum is close enough to whatever GEnum does
class GEnum(int, Enum):
    __gtype__: GType
    value_name: str
    value_nick: str

class BindingFlags(GFlags):
    DEFAULT = ...
    BIDIRECTIONAL = ...
    SYNC_CREATE = ...
    INVERT_BOOLEAN = ...

class ConnectFlags(GFlags):
    AFTER = ...
    SWAPPED = ...


class ParamFlags(GFlags):
    READABLE = ...
    WRITABLE = ...
    READWRITE = ...
    CONSTRUCT = ...
    CONSTRUCT_ONLY = ...
    LAX_VALIDATION = ...
    STATIC_NAME = ...
    PRIVATE = ...
    STATIC_NICK = ...
    STATIC_BLURB = ...
    EXPLICIT_NOTIFY = ...
    DEPRECATED = ...

class SignalFlags(GFlags):
    RUN_FIRST = ...
    RUN_LAST = ...
    RUN_CLEANUP = ...
    NO_RECURSE = ...
    DETAILED = ...
    ACTION = ...
    NO_HOOKS = ...
    MUST_COLLECT = ...
    DEPRECATED = ...
    ACCUMULATOR_FIRST_RUN = ...

class SignalMatchType(GFlags):
    ID = ...
    DETAIL = ...
    CLOSURE = ...
    FUNC = ...
    DATA = ...
    UNBLOCKED = ...

class TypeDebugFlags(GFlags):
    NONE = ...
    OBJECTS = ...
    SIGNALS = ...
    INSTANCE_COUNT = ...
    MASK = ...

class TypeFlags(GFlags):
    ABSTRACT = ...
    VALUE_ABSTRACT = ...

class TypeFundamentalFlags(GFlags):
    CLASSED = ...
    INSTANTIATABLE = ...
    DERIVABLE = ...
    DEEP_DERIVABLE = ...




from gi.repository import GObject

_namespace: str = ...
_version: str = ...

def module_build_path(*args, **kwargs): ...
def module_error(*args, **kwargs): ...
def module_supported(*args, **kwargs): ...

class Module:
    def build_path(*args, **kwargs): ...
    def close(*args, **kwargs): ...
    def error(*args, **kwargs): ...
    def make_resident(*args, **kwargs): ...
    def name(*args, **kwargs): ...
    def supported(*args, **kwargs): ...
    def symbol(*args, **kwargs): ...
    

class ModuleFlags(GObject.GFlags):
    LAZY = ...
    LOCAL = ...
    MASK = ...
